HandlingActionsAndDataOfChapters class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

listOfChapterOfArabic List<Type>
getter/setter pair
listOfChapterOfPhonetics List<Type>
getter/setter pair
math String
getter/setter pair

Static Methods

getArabicChapterBackground({required String programName, required BasicOfGameData gameData}) String?
getTheChapterDataType({required String subLetter, required String subGame, required String unitName, required String programName, required int audioFlag, required String lessonName, required String stageName, required String gameName, required String mobLessonName}) → dynamic
getTheStarsAddState(int number) List<int>
isArabic({required Type chapter}) bool
isPhonetics({required Type chapter}) bool