MainDataOfChapters class abstract
- Implementers
- APhonetics
- BlueUnit
- BPhonetics
- ConnectionSortingCups
- ConnectionWithoutSortingCups
- ConsonantVowels
- CPhonetics
- Culture
- DPhonetics
- EPhonetics
- FirstUnitArabic
- FPhonetics
- GPhonetics
- GreenUnit
- HPhonetics
- IPhonetics
- JPhonetics
- KPhonetics
- LPhonetics
- MathProgram
- MPhonetics
- NPhonetics
- OPhonetics
- OrangeUnit
- PPhonetics
- QPhonetics
- RedPhonetics
- RPhonetics
- RUnitArabic
- RUnitPhonics
- ShortVowels
- SPhonetics
- TPhonetics
- UPhonetics
- UpVowels
- VioletUnit
- VPhonetics
- WPhonetics
- XPhonetics
- YellowUnit
- YPhonetics
- ZPhonetics
Constructors
Properties
- background ↔ String
-
getter/setter pair
- backGroundOfStarBar ↔ Color
-
getter/setter pair
- gameData ↔ BasicOfGameData?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isArabic ↔ bool?
-
getter/setter pair
-
lettersModel
↔ List<
TraceModel> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited