MathChooseOEDomino class

Implemented types

Constructors

MathChooseOEDomino({required ToolsOfMath tools})

Properties

completeBasket String?
getter/setter pairoverride
countOfMinimizeStar int
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
isConnect bool
getter/setter pairoverride
isRound bool
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleImageAr String?
getter/setter pairoverride
titleImageEn String
getter/setter pairoverride
tools ↔ ToolsOfMath
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited