TraceModel class
Constructors
- TraceModel({double? distanceToCheck, double? scaledottedPath, double? scaleIndexPath, Size? poitionIndexPath, Size? poitionDottedPath, PaintingStyle? indexPathPaintStyle, PaintingStyle? dottedPathPaintStyle, double strokeWidth = 55, Color indexColor = Colors.black, Color outerPaintColor = Colors.red, Color innerPaintColor = Colors.blue, Color dottedColor = Colors.amber, required String dottedPath, required String indexPath, required String letterPath, required String pointsJsonFile})
Properties
- distanceToCheck → double?
-
final
- dottedColor → Color
-
final
- dottedPath → String
-
final
- dottedPathPaintStyle → PaintingStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexColor → Color
-
final
- indexPath → String
-
final
- indexPathPaintStyle → PaintingStyle?
-
final
- innerPaintColor → Color
-
final
- letterPath → String
-
final
- outerPaintColor → Color
-
final
- pointsJsonFile → String
-
final
- poitionDottedPath → Size?
-
final
- poitionIndexPath → Size?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaledottedPath → double?
-
final
- scaleIndexPath → double?
-
final
- strokeWidth → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited